@@ -14,7 +14,7 @@ from reV.pipeline.status import Status
 
 from rex.utilities.cli_dtypes import STR, STRLIST, PATHLIST, INT
 from rex.utilities.loggers import init_mult
-from rex.utilities.execution import SLURM
+from rex.utilities.hpc import SLURM
 from rex.utilities.utilities import get_class_properties
 
 logger = logging.getLogger(__name__)
@@ -303,34 +303,42 @@ def multi_year_slurm(ctx, alloc, walltime, feature, memory, conda_env,
     my_file = ctx.obj['MY_FILE']
     verbose = any([verbose, ctx.obj['VERBOSE']])
 
+    slurm_manager = ctx.obj.get('SLURM_MANAGER', None)
+    if slurm_manager is None:
+        slurm_manager = SLURM()
+        ctx.obj['SLURM_MANAGER'] = slurm_manager
+
     status = Status.retrieve_job_status(os.path.dirname(my_file), 'multi-year',
-                                        name)
+                                        name, hardware='eagle',
+                                        subprocess_manager=slurm_manager)
+
     if status == 'successful':
         msg = ('Job "{}" is successful in status json found in "{}", '
                'not re-running.'
                .format(name, os.path.dirname(my_file)))
+    elif 'fail' not in str(status).lower() and status is not None:
+        msg = ('Job "{}" was found with status "{}", not resubmitting'
+               .format(name, status))
     else:
         logger.info('Running reV multi-year collection on SLURM with node '
                     ' name "{}", collecting into "{}".'
                     .format(name, my_file))
         # create and submit the SLURM job
         slurm_cmd = get_slurm_cmd(name, my_file, group_params, verbose=verbose)
-        slurm = SLURM(slurm_cmd, alloc=alloc, memory=memory, walltime=walltime,
-                      feature=feature, name=name, stdout_path=stdout_path,
-                      conda_env=conda_env, module=module)
-        if slurm.id:
+        out = slurm_manager.sbatch(slurm_cmd, alloc=alloc, memory=memory,
+                                   walltime=walltime, feature=feature,
+                                   name=name, stdout_path=stdout_path,
+                                   conda_env=conda_env, module=module)
+        if out:
             msg = ('Kicked off reV multi-year collection job "{}" '
-                   '(SLURM jobid #{}).'.format(name, slurm.id))
+                   '(SLURM jobid #{}).'.format(name, out))
             # add job to reV status file.
             Status.add_job(
                 os.path.dirname(my_file), 'multi-year', name, replace=True,
-                job_attrs={'job_id': slurm.id, 'hardware': 'eagle',
+                job_attrs={'job_id': out, 'hardware': 'eagle',
                            'fout': os.path.basename(my_file),
                            'dirout': os.path.dirname(my_file)})
-        else:
-            msg = ('Was unable to kick off reV collection job "{}". '
-                   'Please see the stdout error messages'
-                   .format(name))
+
     click.echo(msg)
     logger.info(msg)
 
