@@ -14,7 +14,8 @@ from reV.pipeline.status import Status
 from reV.utilities.exceptions import ExecutionError
 
 from rex.utilities import safe_json_load
-from rex.utilities.execution import SubprocessManager, SLURM
+from rex.utilities.execution import SubprocessManager
+from rex.utilities.hpc import SLURM
 from rex.utilities.loggers import init_logger
 
 logger = logging.getLogger(__name__)
@@ -76,8 +77,10 @@ class Pipeline:
     def _cancel_all_jobs(self):
         """Cancel all jobs in this pipeline via SLURM scancel."""
         status = self._get_status_obj()
+        s = SLURM()
         for job_id in status.job_ids:
-            SLURM.scancel(job_id)
+            s.scancel(job_id)
+        logger.info('Pipeline job "{}" cancelled.'.format(self._config.name))
 
     def _main(self):
         """Iterate through run list submitting steps while monitoring status"""
@@ -218,7 +221,8 @@ class Pipeline:
             reV job status object.
         """
 
-        status = Status(self._config.dirout, name=self._config.name)
+        status = Status(self._config.dirout, name=self._config.name,
+                        hardware=self._config.hardware)
         return status
 
     def _get_module_return_code(self, status, module):
@@ -355,6 +359,7 @@ class Pipeline:
                .format(f_config, command))
         if verbose:
             cmd += ' -v'
+
         return cmd
 
     @staticmethod
